@@ -20,6 +20,16 @@ from unique_sdk._request_options import RequestOptions
 class Content(APIResource["Content"]):
     OBJECT_NAME: ClassVar[Literal["content.search"]] = "content.search"
 
+    id: str
+    key: str
+    url: Optional[str]
+    title: Optional[str]
+    updatedAt: str
+    chunks: Optional[List["Content.Chunk"]]
+    metadata: Optional[Dict[str, Any]]
+    writeUrl: Optional[str]
+    readUrl: Optional[str]
+
     class QueryMode(Enum):
         Default = "default"
         Insensitive = "insensitive"
@@ -127,6 +137,7 @@ class Content(APIResource["Content"]):
         key: str
         title: Optional[str]
         mimeType: str
+        description: NotRequired[str | None]
         ownerType: NotRequired[str | None]
         ownerId: NotRequired[str | None]
         byteSize: NotRequired[int | None]
@@ -168,6 +179,7 @@ class Content(APIResource["Content"]):
         title: str | None
         metadata: Dict[str, Any] | None
         mimeType: str
+        description: str | None
         byteSize: int
         ownerId: str
         createdAt: str
@@ -192,16 +204,6 @@ class Content(APIResource["Content"]):
     class DeleteResponse(TypedDict):
         id: str
 
-    id: str
-    key: str
-    url: Optional[str]
-    title: Optional[str]
-    updatedAt: str
-    chunks: List[Chunk]
-    metadata: Optional[Dict[str, Any]]
-    writeUrl: str
-    readUrl: str
-
     class MagicTableSheetTableColumn(TypedDict):
         columnId: str
         columnName: str
@@ -349,6 +351,9 @@ class Content(APIResource["Content"]):
         """
         if "input" in params:
             params["input"]["metadata"] = params["input"].get("metadata") or {}
+            if "description" in params["input"] and not params["input"]["description"]:
+                params["input"].pop("description")
+
         return cast(
             "Content",
             cls._static_request(
@@ -372,6 +377,9 @@ class Content(APIResource["Content"]):
         """
         if "input" in params:
             params["input"]["metadata"] = params["input"].get("metadata") or {}
+            if "description" in params["input"] and not params["input"]["description"]:
+                params["input"].pop("description")
+
         return cast(
             "Content",
             await cls._static_request_async(
