@@ -38,6 +38,7 @@ def upload_file(
     path_to_file,
     displayed_filename,
     mime_type,
+    description: Optional[str] = None,
     scope_or_unique_path=None,
     chat_id=None,
     ingestion_config: Optional[Content.IngestionConfig] = None,
@@ -55,6 +56,7 @@ def upload_file(
             "key": displayed_filename,
             "title": displayed_filename,
             "mimeType": mime_type,
+            "description": description,
             "ingestionConfig": ingestion_config,
             "metadata": metadata,
         },
@@ -83,6 +85,7 @@ def upload_file(
                 "key": displayed_filename,
                 "title": displayed_filename,
                 "mimeType": mime_type,
+                "description": description,
                 "byteSize": size,
                 "ingestionConfig": ingestion_config,
                 "metadata": metadata,
@@ -98,6 +101,7 @@ def upload_file(
                 "key": displayed_filename,
                 "title": displayed_filename,
                 "mimeType": mime_type,
+                "description": description,
                 "byteSize": size,
                 "ingestionConfig": ingestion_config,
                 "metadata": metadata,
